# Project

Project information. Contributions are welcome.

:::{rubric} Operations
:::
```{toctree}
:maxdepth: 1

caveats
```

:::{rubric} Development
:::
```{toctree}
:maxdepth: 1

sandbox
../changes
../backlog
prior-art
```
